## Features

This package will throw [Django system checks](https://docs.djangoproject.com/en/dev/topics/checks/)
warnings for all known removals from Django v1.0 to today.

Here's an example:

![Example system check](https://raw.githubusercontent.com/ambient-innovation/django-removals/963cdef1f04b9f3f8efbe6a4a893ef4abe911e07/docs/system_check_warning.png?raw=True)

The checks will either be triggered when using the Django development server

`python manage.py runserver`

or when you call the checks manually

`python manage.py check --deploy`

It focuses on Django settings but might also add more checks in the future.
